@@ -6,34 +6,25 @@ Gtk2::Ex::Entry::Pango - Gtk2 Entry that accepts Pango markup.
 
 =head1 SYNOPSIS
 
+	use Gtk2 qw(-init);
+	use Glib qw(TRUE FALSE);
 	use Gtk2::Ex::Entry::Pango;
 	
+	my $window = Gtk2::Window->new();
+	my $entry = Gtk2::Ex::Entry::Pango->new();
 	
 	# You can use any method defined in Gtk2::Entry or set_markup()
-	my $entry = Gtk2::Ex::Entry::Pango->new();
 	$entry->set_markup('<i>Pan</i><b>go</b> is <span color="red">fun</span>');
 	
+	my $vbox = new Gtk2::VBox(FALSE, 0);
+	$vbox->pack_start($entry, FALSE, FALSE, FALSE);
+	$vbox->set_focus_child($entry);
+	$window->add($vbox);
 	
-	# Create a simple search field
-	my $search = Gtk2::Ex::Entry::Pango->new();
-	$search->set_empty_markup("<span color='grey' size='smaller'>Search...</span>");
+	$window->signal_connect(delete_event => sub { Gtk2->main_quit(); });
 	
-	
-	# Realtime validation - accept only ASCII letters
-	my $validation = Gtk2::Ex::Entry::Pango->new();
-	$validation->signal_connect(changed => sub {
-		my $text = $validation->get_text;
-	
-		# Validate the entry's text
-		if ($text =~ /^[a-z]*$/) {
-			return;
-		}
-	
-		# Mark the string as being erroneous
-		my $escaped = Glib::Markup::escape_text($text);
-		$validation->set_markup("<span underline='error' underline_color='red'>$escaped</span>");
-		$validation->signal_stop_emission_by_name('changed');
-	});
+	$window->show_all();
+	Gtk2->main();
 
 =head1 HIERARCHY
 
@@ -49,15 +40,10 @@ C<Gtk2::Ex::Entry::Pango> is a subclass of L<Gtk2::Entry>.
 
 =head1 DESCRIPTION
 
-C<Gtk2::Ex::Entry::Pango> is a C<Gtk2::Entry> that can accept Pango markup for
-various purposes (for more information about Pango text markup language see 
+C<Gtk2::Ex::Entry::Pango> is a C<Gtk2::Entry> that can accept Pango markup as
+input (for more information about Pango text markup language see 
 L<http://library.gnome.org/devel/pango/stable/PangoMarkupFormat.html>).
 
-The widget allows Pango markup to be used for input as an alternative to
-C<set_text> or for setting a default value when the widget is empty. The default
-value when empty is ideal for standalone text entries that have no accompanying
-label (such as a text field for a search).
-
 This widget allows for the text data to be entered either through the normal
 methods provided by C<Gtk2::Entry> or to use the method L</set_markup>. It's
 possible to switch between two methods for applying the text. The standard
@@ -132,66 +118,34 @@ use strict;
 use warnings;
 
 use Glib qw(TRUE FALSE);
-# Gtk2 with Pango support
-use Gtk2 1.100;
-use Gtk2::Pango;
-use Carp;
-
-# Module version
-our $VERSION = '0.06_02';
+use Gtk2;
 
 
-# Emty Pango attributes list that's used to clear the previous markup
-my $EMPTY_ATTRLIST = ($Gtk2::VERSION >= 1.160) 
-	? Gtk2::Pango::AttrList->new() 
-	: Gtk2::Pango->parse_markup('')
-;
+our $VERSION = '0.01';
 
 
 # See http://gtk2-perl.sourceforge.net/doc/pod/Glib/Object/Subclass.html
 use Glib::Object::Subclass 'Gtk2::Entry' =>
 
 	signals => {
-		'changed'            => \&callback_changed,
-		'expose-event'       => \&callback_expose_event,
-		'button-press-event' => \&callback_button_press_event,
+		'changed'        => \&callback_changed,
+		'expose-event'   => \&callback_expose_event,
 
 		'markup-changed' => {
 			flags       => ['run-last'],
 			param_types => ['Glib::String'],
-		},
-
-		'empty-markup-changed' => {
-			flags       => ['run-last'],
-			param_types => ['Glib::String'],
-		},
+		}
 	},
 
 
 	properties => [
 		Glib::ParamSpec->string(
 			'markup',
-			'Markup',
+			'markup',
 			'The Pango markup used for displaying the contents of the entry.',
 			'',
 			['writable'],
 		),
-
-		Glib::ParamSpec->string(
-			'empty-markup',
-			'Markup when empty',
-			'The default Pango markup to display when the entry is empty.',
-			'',
-			['readable', 'writable'],
-		),
-
-		Glib::ParamSpec->boolean(
-			'clear-on-focus',
-			'Clear the markup when the widget has focus',
-			'If the Pango markup to display has to cleared when the entry has focus.',
-			TRUE,
-			['readable', 'writable'],
-		),
 	],
 ;
 
@@ -206,10 +160,6 @@ sub INIT_INSTANCE {
 	# The Pango attributes to apply to the text. If set to undef then there are no
 	# attributes and the text is rendered normally.
 	$self->{attributes} = undef;
-	
-	# The Pango text and attributes to apply when the entry has no text.
-	$self->{'empty_attributes'} = undef;
-	$self->{'empty_text'} = undef;
 }
 
 
@@ -227,19 +177,6 @@ sub SET_PROPERTY {
 		# stored.
 		$self->apply_markup($value);
 	}
-	elsif ($field eq 'empty_markup') {
-		if (defined $value) {
-			($self->{empty_attributes}, $self->{empty_text}) = Gtk2::Pango->parse_markup($value);
-		}
-		else {
-			($self->{empty_attributes}, $self->{empty_text}) = (undef, undef);
-		}
-		$self->{$field} = $value;
-		$self->signal_emit('empty-markup-changed' => $value);
-	}
-	else {
-		$self->{$field} = $value;
-	}
 }
 
 
@@ -262,9 +199,10 @@ XML.
 
 You might want to use the following code snippet for escaping the characters:
 
+	use Glib::Markup qw(escape_text);
 	$entry->set_markup(
 		sprintf "The <i>%s</i> <b>%s</b> fox <sup>%s</sup> over the lazy dog",
-			map { Glib::Markup::escape_text($_) } qw(quick brown jumps)
+			map { escape_text($_) } ('quick', 'brown', 'jumps')
 	);
 
 =back	
@@ -275,6 +213,7 @@ sub set_markup {
 	my $self = shift;
 	my ($markup) = @_;
 
+	#
 	# NOTE: In order to have the markup applied properly both the widget's
 	# internal text value and the Pango style have to be applied. Calling
 	# $self->get_layout->set_markup($markup); is not enough as it will only apply
@@ -293,6 +232,8 @@ sub set_markup {
 	# style has to be applied afterwards. The text is added to the widget through
 	# $self->set(text => $text); by the method apply_markup() while the styles are
 	# applied each time that the widget is rendered (see callback_changed()).
+	#
+
 	$self->set(markup => $markup);
 }
 
@@ -314,91 +255,6 @@ sub clear_markup {
 
 
 
-=head2 set_empty_markup
-
-Sets the Pango markup that was applied to the widget when there's the entry is
-empty. This method can die if the markup is not valid and fails to parse
-(see L<Gtk2::Pango/parse_markup>).
-
-C<NOTE:> Setting an empty markup string has no effect on C<get_text>. When an
-empty markup string is used the entry holds no data thus C<get_text> will return
-an empty string.
-
-Parameters:
-
-=over
-
-=item * $markup
-
-The text to add to the entry, the text is expected to be using Pango markup.
-Make sure to escape all characters with L<Glib::Markup/escape_text>. For more
-details about escaping the markup see L</set_markup>.
-
-=back	
-
-=cut
-
-sub set_empty_markup {
-	my $self = shift;
-	my ($markup) = @_;
-	$self->set(empty_markup => $markup);
-}
-
-
-
-=head2 clear_empty_markup
-
-Clears the Pango markup that was applied to the widget. This method can be
-called even if no markup was applied previously.
-
-=cut
-
-sub clear_empty_markup {
-	my $self = shift;
-	$self->set_empty_markup(undef);
-}
-
-
-
-=head2 get_clear_on_focus
-
-Returns if the widget's Pango markup will be cleared once the widget is focused
-and has no user text.
-
-=cut
-
-sub get_clear_on_focus {
-	my $self = shift;
-	return $self->get('clear_on_focus');
-}
-
-
-
-=head2 set_clear_on_focus
-
-Returns if the widget's Pango markup will be cleared once the widget is focused
-and has no user text.
-
-Parameters:
-
-=over
-
-=item * $value
-
-A boolean value that dictates if the Pango markup has to be cleared when the
-widget is focused and there's no text entered (the entry is empty).
-
-=back	
-
-=cut
-
-sub set_clear_on_focus {
-	my $self = shift;
-	my ($value) = @_;
-	return $self->set(clear_on_focus => $value);
-}
-
-
 #
 # Applies the markup to the widget. The markup string is parsed into a text to
 # be displayed and an attribute list (the styles to apply). The text is added
@@ -424,13 +280,13 @@ sub apply_markup {
 		$self->request_redraw();
 	}
 	else {
-		# Change the entry's text. Mark this as an internal change as we can't let
+		# Change the entry's text. Mark this as an internal change as a we can't let
 		# the 'changed' callback reset the markup.
 		local $self->{internal} = TRUE;		
 		$self->set(text => $text);
 		
 		if ($self->{internal}) {
-			# The signal 'changed' wasn't emited (it can happen sometimes) so lets
+			# The signal 'changed' wasn't emited (it can happen sometimes) so let's
 			# request a refresh of the UI manually.
 			$self->request_redraw();
 		}
@@ -483,31 +339,11 @@ sub signal_emit_markup_changed {
 #
 sub set_layout_attributes {
 	my $self = shift;
-
-	if ($self->get_text ne '') {
-		# There's text in the widget apply the attributes (the requested pango
-		# text). If the're attributes simply clear the previous ones.
-		my $attributes = $self->{attributes};
-		if (! defined $attributes) {
-			# Clear the previous attributes, just in case...
-			$attributes = $EMPTY_ATTRLIST;
-		}
-		$self->get_layout->set_attributes($attributes);
-	}
-	elsif ($self->get_clear_on_focus and $self->has_focus) {
-		# The widget has focus and is empty, if the user requested that it be
-		# cleared when focused we have to honor it here.
-		my $attributes = $EMPTY_ATTRLIST;
-		$self->get_layout->set_text('');
-		$self->get_layout->set_attributes($attributes);
-		return;
-	}
-	elsif ($self->{empty_markup}) {
-		# The widget is empty and the user wants it filled with a default text at
-		# all times.
-		$self->get_layout->set_text($self->{empty_text});
-		$self->get_layout->set_attributes($self->{empty_attributes});
+	my $attributes = $self->{attributes};
+	if (! defined $attributes) {
+		$attributes = Gtk2::Pango::AttrList->new();
 	}
+	$self->get_layout->set_attributes($attributes);
 }
 
 
@@ -553,31 +389,7 @@ sub callback_expose_event {
 	my ($event) = @_;
 
 	$self->set_layout_attributes();
-	return $self->signal_chain_from_overridden(@_);
-}
-
-
-
-#
-# This handler stops the widget from generating critical Pango warnings when the
-# text selection gesture is performed. If there's no text in the widget we
-# simply cancel the gesture.
-#
-# The gesture is done with: mouse button 1 pressed and dragged over the widget
-# while the button is still pressed.
-#
-sub callback_button_press_event {
-	my $self = shift;
-	my ($event) = @_;
-	
-	if ($self->get_text or $event->button != 1) {
-		# Propagate the event further since there's text in the widget
-		return $self->signal_chain_from_overridden(@_);
-	}
-	
-	# Give focus to the widget but stop the text selection
-	$self->grab_focus();
-	return TRUE;
+	$self->signal_chain_from_overridden(@_);
 }
 
 
@@ -597,14 +409,6 @@ The markup text used by this widget. This property is a string that's only
 writable. That's right, there's no way for extracting the markup from the
 widget.
 
-=head2 empty-markup
-
-(string: readable writable)
-
-The markup text used by this widget when the entry field is empty. If this
-property is set the entry will display a default string in the widget when
-there's no text provided by the user.
-
 =head1 SIGNALS
 
 =head2 markup-changed
@@ -629,28 +433,6 @@ C<$markup> is C<undef> then the markup was removed.
 
 =back	
 
-=head2 empty-markup-changed
-
-Emitted when the markup used when the widget is empty has been changed.
-
-Signature:
-
-	sub empty_markup_changed {
-		my ($widget, $markup) = @_;
-		# Returns nothing
-	}
-
-Parameters:
-
-=over
-
-=item * $markup
-
-The new markup that's been applied when the widget is empty. This field is a
-normal Perl string. If C<$markup> is C<undef> then the markup was removed.
-
-=back	
-
 =head1 SEE ALSO
 
 Take a look at the examples for getting some ideas or inspiration on how to use
